The caveat is not a real constraint, since Org has limited support for
source block editing in an Org mode buffer when an
`org-babel-edit-prep:<LANG>' function signals an user-error.  Demo:

#+begin_src emacs-lisp -n :results silent
;; Limited source block editing in an Org buffer.
(defun edit-prep-user-error (_info)
  (user-error "Signaling user-errors is harmfull"))

(defun org-babel-edit-prep:python (info)
  (edit-prep-user-error info))
#+end_src

#+begin_src emacs-lisp -n :results silent
;; Supports source block editing in an Org buffer.
(defun edit-prep-message (_info)
  (message "Displaying messages is harmless"))

(defun org-babel-edit-prep:python (info)
  (edit-prep-message info))
#+end_src

When org-babel-edit-prep:python displays a message and without using
M-x org-edit-src-code, it is possible to insert newlines like any
other character in the block below:

#+begin_src python -i -n :results silent
# comment
#+end_src

But when org-babel-edit-prep:python signals an user-error, inserting a
newline differs from inserting other characters:
1. The newline gets inserted but the edit buffer changes state (turns
   yellow on my system)
2. Typing any character does not work, but I get in the message buffer:
   - "Cannot modify an area being edited in a dedicated buffer"
3. After M-x org-edit-src-code I get in the message buffer:
   - "Return to existing edit buffer ([n] will revert changes)? (y or n) y"
   - "edit-prep-user-error: Signaling user-errors is harmfull"
4. It is possible to go back immediately to the Org mode buffer to
   insert a character sequence (terminated by a newline that changes
   the state of the edit buffer back to 1).
When org-babel-edit-prep:python displays a message, I never see
turning the state of an Org source buffer to "dedicated" when editing
the block in an Org mode buffer.






I am sure that the "dedicated" state of the Org source buffer is
related to the warnings: "Warning (org-element):
‘org-element-at-point’ cannot be used in non-Org buffer #<buffer *Org
Src no-user-errors-in-edit-prep.org[ python ]*> (python-mode)" when I
try to split the blocks by demarcation with the patch.

#+begin_src emacs-lisp -n :results silent
(condition-case nil
    (user-error "Hidden")
  (user-error "Shown"))
#+end_src
